TcsCustomSelectionDialog class

彈跳視窗:選擇視窗樣式(Custom Selection Dialog)

變更記錄:

  • Last Modified: 2025-03-11
    • fix: 修正滾動邏輯,避免超出可滾動範圍
    • refactor: 調整動畫持續時間與曲線,使體驗更流暢

Modify By: IF

Inheritance

Constructors

TcsCustomSelectionDialog({Key? key, String? title = "請選擇", String? buttonText = "取消", required List<CustomSelectionDialogOptionItem> items, dynamic onItemSelected(CustomSelectionDialogOptionItem selectedItem)?, int? initialSelectedIndex, int itemCountThreshold = 6, int scrollOffsetThreshold = 3})
彈跳視窗:選擇視窗樣式
const

Properties

buttonText String?
final
hashCode int
The hash code for this object.
no setterinherited
initialSelectedIndex int?
final
itemCountThreshold int
final
items List<CustomSelectionDialogOptionItem>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onItemSelected → dynamic Function(CustomSelectionDialogOptionItem selectedItem)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollOffsetThreshold int
final
title String?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CustomSelectionDialogState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showExample(BuildContext context, {bool useNativeDialog = false, void onItemSelected(CustomSelectionDialogOptionItem)?}) → void
靜態範例:顯示選擇彈窗