CustomSelectionDialogOptionItem class
共用 選擇視窗的類別
Constructors
- CustomSelectionDialogOptionItem({required String label, required dynamic value, bool isSelected = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSelected ↔ bool
-
是否被選中
getter/setter pair
- label ↔ String
-
顯示用名稱
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ dynamic
-
實際業務邏輯需要使用的值
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - 將實例轉換為 JSON 格式
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited